@@ -7,29 +7,28 @@ Python library to download YouTube content and retrieve metadata
 
 https://github.com/np1/pafy
 
-Copyright (C)  2013-2014 nagev
+Copyright (C)  2013-2014 np1
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+This program is free software: you can redistribute it and/or modify it under
+the terms of the GNU Lesser General Public License as published by the Free
+Software Foundation, either version 3 of the License, or (at your option) any
+later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+This program is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+You should have received a copy of the GNU Lesser General Public License along
+with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
 
 from __future__ import unicode_literals
 
-__version__ = "0.3.66"
-__author__ = "nagev"
-__license__ = "GPLv3"
+__version__ = "0.3.68"
+__author__ = "np1"
+__license__ = "LGPLv3"
 
 
 import re
@@ -95,8 +94,8 @@ def fetch_decode(url, encoding=None):
         return req.read().decode(encoding)
 
     elif "charset=" in ct:
+        dbg("charset: %s", ct)
         encoding = re.search(r"charset=([\w-]+)\s*(:?;|$)", ct).group(1)
-        dbg("encoding detected: %s", ct)
         return req.read().decode(encoding)
 
     else:
@@ -1352,14 +1351,15 @@ class Pafy(object):
         self._fetch_gdata()
         return self._dislikes
 
-    def getbest(self, preftype="any", ftypestrict=True):
+    def _getbest(self, preftype="any", ftypestrict=True, vidonly=False):
         """
-        Return the best resolution available.
+        Return the highest resolution video available.
 
-        set ftypestrict to False to use a non preferred format if that
-        has a higher resolution
+        Select from video-only streams if vidonly is True
         """
-        if not self.streams:
+        streams = self.videostreams if vidonly else self.streams
+
+        if not streams:
             return None
 
         def _sortkey(x, key3d=0, keyres=0, keyftype=0):
@@ -1371,7 +1371,7 @@ class Pafy(object):
             nonstrict = (key3d, keyres, keyftype)
             return strict if ftypestrict else nonstrict
 
-        r = max(self.streams, key=_sortkey)
+        r = max(streams, key=_sortkey)
 
         if ftypestrict and preftype != "any" and r.extension != preftype:
             return None
@@ -1379,6 +1379,24 @@ class Pafy(object):
         else:
             return r
 
+    def getbestvideo(self, preftype="any", ftypestrict=True):
+        """
+        Return the best resolution video-only stream.
+
+        set ftypestrict to False to return a non-preferred format if that
+        has a higher resolution
+        """
+        return self._getbest(preftype, ftypestrict, vidonly=True)
+
+    def getbest(self, preftype="any", ftypestrict=True):
+        """
+        Return the highest resolution video+audio stream.
+
+        set ftypestrict to False to return a non-preferred format if that
+        has a higher resolution
+        """
+        return self._getbest(preftype, ftypestrict, vidonly=False)
+
     def getbestaudio(self, preftype="any", ftypestrict=True):
         """ Return the highest bitrate audio Stream object."""
         if not self.audiostreams:
